@@ -1,20 +1,19 @@
-use std::collections::HashMap;
-use std::fmt::{Display, Formatter};
+mod traits;
+use std::{
+    collections::HashMap,
+    fmt::{Display, Formatter},
+};
+
 
 #[derive(Clone, Debug)]
 pub struct BreakPointSystem {
     inner: HashMap<String, BreakPoint>,
 }
 
-impl Default for BreakPointSystem {
-    fn default() -> Self {
-        Self {
-            inner: Default::default()
-        }
-    }
-}
 
 impl BreakPointSystem {
+    /// Builtin ranges
+    /// https://tailwindcss.com/docs/screens
     pub fn builtin() -> Self {
         let mut new = Self::default();
         new.register("sm".to_string(), 640);
@@ -22,19 +21,15 @@ impl BreakPointSystem {
         new.register("lg".to_string(), 1024);
         new.register("xl".to_string(), 1280);
         new.register("2xl".to_string(), 1536);
-        return new
+        return new;
     }
 
     #[inline]
     pub fn register(&mut self, name: String, width: usize) -> Option<BreakPoint> {
-        self.inner.insert(name, BreakPoint {
-            width
-        })
+        self.inner.insert(name, BreakPoint { width })
     }
 }
 
-
-/// sm	640px	@media (min-width: 640px) { ... }
 #[derive(Clone, Debug)]
 pub struct BreakPoint {
     /// min-width
@@ -42,8 +37,3 @@ pub struct BreakPoint {
     width: usize,
 }
 
-impl Display for BreakPoint {
-    fn fmt(&self, f: &mut Formatter<'_>) -> std::fmt::Result {
-        todo!()
-    }
-}
\ No newline at end of file
